<?php
/*
Plugin Name: Custom Post Types
Plugin URI: http://YourWebsiteEngineer.com
Description: Here are the custom post types for my website
Version: 1.0
Author: Dustin Hartzler
Author URI: http://YourWebsiteEngineer.com
*/

class DH_Movies_Post_Type{
	public function __construct(){
		$this->register_post_type();
		$this->taxonomies();
		$this->metaboxes();
	}

	public function register_post_type(){
		$labels = array (
			'name'				 => 'Movie Selection',
			'singular_name'		 => 'Movie',
			'add_new'            => 'Add New Movie',
			'add_new_item'       => 'Add New Movie',
			'edit_item'          => 'Edit Movie',
			'new_item'           => 'New Movie',
			'all_items'          => 'All Movies',
			'view_item'          => 'View Movies',
			'search_items'       => 'Search All Movies',
			'not_found'        	 => 'Nothing found',
			'not_found_in_trash' => 'Nothing found in the Trash', 
			'parent_item_colon'  => '',
			'menu_name'          => 'Awesome Movies'

			);
		$args = array (
			'labels' 		=> $labels,
			'description' 	=> 'This section hold all of our movies',
			'public'		=> true,
			'menu_position'	=> 6,
			// 'menu_icon'		=> get_stylesheet_directory_uri() .'images/movie_art.png'
			'supports'		=> array('title', 'editor', 'thumbnail', 'comments', 'excerpt','custom-fields')
			);
		register_post_type ('dh_movies', $args);
	}
	public function taxonomies(){
		$taxonomies = array();

		$taxonomies['genre'] = array (
			'query_var'		=> 'movie_var',
			'hierachical'	=> true,
			'rewrite'		=> array ( 'slug' => 'movies/genre'),
			'labels'		=> array (
				'name' 				=> 'Genre',
				'singular_name' 	=> 'Genre',
				'search_items'		=> 'Search Genre', 	
				'all_items' 		=> 'All Genre',
				'parent_item' 		=> 'Parent Genre',
				'parent_item_colon' => 'Parent Genre',
				'edit_item' 		=> 'Edit Genre',
				'update_item' 		=> 'Update Genre',
				'add_new_item' 		=> 'Add New Genre',
				'new_item_name' 	=> 'New Genre Name',
				'menu_name' 		=> 'Genre'
				)
			);
		$taxonomies['studio'] = array (
			'query_var'		=> 'movie_var',
			'hierachical'	=> true,
			'rewrite'		=> array ( 'slug' => 'movies/studio'),
			'labels'		=> array (
				'name' 				=> 'Studio',
				'singular_name' 	=> 'Studio',
				'search_items'		=> 'Search Studio', 	
				'all_items' 		=> 'All Studio',
				'parent_item' 		=> 'Parent Studio',
				'parent_item_colon' => 'Parent Studio',
				'edit_item' 		=> 'Edit Studio',
				'update_item' 		=> 'Update Studio',
				'add_new_item' 		=> 'Add New Studio',
				'new_item_name' 	=> 'New Studio Name',
				'menu_name' 		=> 'Studio'
				)
			);
		$this->register_all_taxonomies($taxonomies);
	}

	public function register_all_taxonomies($taxonomies){
		foreach ($taxonomies as $name => $arr) {
			register_taxonomy ($name, array(dh_movies), $arr);
		}
		
	}
	public function metaboxes(){
		add_action('add_meta_boxes', function(){
			add_meta_box ('dh_movie_length', 'Movie Length', 'movie_length', 'dh_movies');
		});
		function movie_length($post){
			$length = get_post_meta($post->ID, 'dh_movie_length', true);
			$format = get_post_meta($post->ID, 'dh_movie_format', true);
			?>
			<p>
				<table>
				<td>
				<label for="dh_movie_length">Length: </label>
				<input type="text" class="widefat" name="dh_movie_length" id="dh_movie_length" 
				value="<?php echo esc_attr($length); ?>"?>
			</td>
			<td>
				<label for="dh_movie_format">Format: </label>
				<input type="text" class="widefat" name="dh_movie_format" id="dh_movie_format" 
				value="<?php echo esc_attr($format); ?>"?>
			</td>
				</table>
			</p>
			<?php
		}
		add_action('save_post', function($id){
			if (isset($_POST['dh_movie_length'])){
				update_post_meta($id, 'dh_movie_length', strip_tags($_POST['dh_movie_length']));
			}
			if (isset($_POST['dh_movie_format'])){
				update_post_meta($id, 'dh_movie_format', strip_tags($_POST['dh_movie_format']));
			}
		});
	}
}

add_action('init', function(){
	new DH_Movies_Post_Type();
});